#!/bin/bash
 
#SBATCH -n 1
#SBATCH -t 120:00:00
#SBATCH -J oras4_O1L46
#SBATCH --mail-user <chloe.prodhomme@ic3.cat>
#SBATCH --mail-type FAIL
#SBATCH -o oras4_O1L46-%j.out
#SBATCH -e oras4_O1L46-%j.err

set -evx

year0=${1}
yearf=${2}
fc0=0
fcf=4
lstMM=${3}
config=${4} #'O1L46'
TMPDIR=${5}
maskout=$6
Ptoextrap=$7
Ptofillclim=$8

#mkdir $TMPDIR
cd $TMPDIRb
cp /shared/earth/software/scripts/prep_restarts/library/comp_rhop_$config comp_rhop
cp ~/tools/cfutools/prep_restarts/script_interp_vert_ocean_restart.bash .
inputdir=/esnas/releases/ic/ocean/ORCA1/s4_original_file/
outputdir=/esnas/releases/ic/ocean/${config/O/ORCA}/s4

for ((year=${year0};year<=${yearf};year++)) ; do
 for ((fc=${fc0};fc<=${fcf};fc++)) ; do
  for MM in $lstMM ; do
      filein=s4_fc${fc}_${year}${MM}_restart.nc.gz
      #check if the interpolated restart already exists
      if [ ! -e  $outputdir/$filein ]; then
	  cp $inputdir/$filein  .
	  gunzip $filein
	  # Vertical interpolation + horizontal and vertical extrapolation + filling empty seas 
	  
	  bash script_interp_vert_ocean_restart.bash s4_fc${fc}_${year}${MM}_restart s4_fc${fc}_${year}${MM}_restart_${config} 0$((${MM:0:2}+1)) ${config/O/ORCA} $maskout $Ptoextrap $Ptofillclim 
	  # rhop needs to be added for EC-Earth3 ; computed from tn and sn
	  cat > namelist_rhop <<EOF
&density
  input_file = 's4_fc${fc}_${year}${MM}_restart_${config}.nc'
  input_Tvar = 'tn'
  input_Svar = 'sn'
  input_Dvar = 'nav_lev'
  outfile    = 'rhop_fc${fc}_${year}${MM}.nc'
/
EOF
	  ./comp_rhop
	  ncwa -O -a t rhop_fc${fc}_${year}${MM}.nc rhop_fc${fc}_${year}${MM}.nc
	  ncks -A rhop_fc${fc}_${year}${MM}.nc s4_fc${fc}_${year}${MM}_restart_${config}.nc
	  # The output restart is masked to be able to check the mask
	  # but EC-Earth does not accept masks
	  cdo setmisstoc,0 s4_fc${fc}_${year}${MM}_restart_${config}.nc tmp.nc; rm -f s4_fc${fc}_${year}${MM}_restart_${config}.nc; mv tmp.nc s4_fc${fc}_${year}${MM}_restart_${config}.nc 
          #add a dimension time
	  restart_out=s4_fc${fc}_${year}${MM}_restart_${config}
	  ncecat ${restart_out}.nc  ${restart_out}_time.nc
	  ncrename -O -d record,t ${restart_out}_time.nc 
	  mv ${restart_out}_time.nc ${restart_out}.nc
	  #remove missing values
	  ncatted -O -a _FillValue,,d,, ${restart_out}.nc
	  ncatted -O -a missing_value,,d,, ${restart_out}.nc
	  # Storage
	  gzip ${restart_out}.nc
	  mv ${restart_out}.nc.gz $outputdir/$filein
	  rm -f ${restart_out} namelist_rhop rhop_fc${fc}_${year}${MM}.nc
      fi
  done
 done
done
#rm -f comp_rhop script_interp_vert_ocean_restart.bash
#rm -rf $TMPDIR
